use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Debug::Table)
                    .if_not_exists()
                    .col(pk_auto(Debug::Id))
                    .col(string(Debug::Title))
                    .col(string(Debug::Text))
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Debug::Table).to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum Debug {
    Table,
    Id,
    Title,
    Text,
}
